/**
 * @file
 * Provides modal feature.
 *
 * The extra line between the end of the @file docblock
 * and the file-closure is important.
 */

'use strict';

(function ($, Drupal, drupalSettings) {
  /**
   * Displays the prehome in a modal.
   *
   * @type {Drupal~behavior}
   *
   * @prop {Drupal~behaviorAttach} attach
   *   Opens the modal.
   */
  Drupal.behaviors.prehomeModal = {
    /**
     * Attach behaviors.
     *
     * @param context
     *   This is the dom element of context.
     */
    attach: function (context) {
      $('#prehome-modal', context).once('prehome-modal').each(function () {
        var displayCount = parseInt($.cookie('prehome_display_count'));
        displayCount = !Number.isInteger(displayCount) ? 0 : displayCount;
        var nbTimesToShow = parseInt(drupalSettings.times_to_show) ? parseInt(drupalSettings.times_to_show) : 1;

        if (displayCount < nbTimesToShow) {
          // Display modal.
          $(this).show();
          Drupal.dialog($(this), {
            title: drupalSettings.title,
            classes: {
              'ui-dialog': drupalSettings.classes,
            },
            draggable: false,
            open: function (event, ui) {
              // Close modal on overlay click.
              $(this).parents().attr('tabindex', -1).focus();

              $(document).click(function (event) {
                if (!$(event.target).closest('.prehome .ui-widget-content').length) {
                  $('.ui-dialog-titlebar-close').click();
                }
              });

              // Increment display count.
              $.cookie('prehome_display_count', displayCount + 1, {path: '/', secure: true});

              // Prevent scroll.
              $('body').css('overflow', 'hidden');
            },
            close: function (event) {
              // Destroy the DOM element that was used for the dialog.
              $(event.target).remove();

              // Allow scroll.
              $('body').css('overflow', '');
            },
          }).showModal();
        }
      });
    }
  };

}(jQuery, Drupal, drupalSettings));
